#!/bin/bash
#===============================================================================
# Renombra recursivamente los espacios de los archivos a guion bajo.
#===============================================================================
#
# Para este código genérico de modificación de nombres de fichero:
#
#find $1 -depth -name '*ñ*' | while read fichero
#do nuevofichero=`echo "$fichero" | sed 's/ñ/n/g'`
#mv "$fichero" "$nuevofichero"
#done
#
# es necesario ejecutarlo varias veces porque find realiza una búsqueda
# inicial con los nombres originales y conforme van cambiando los
# nombres de los directorios llega un momento en que ya no se encuentran
# los ficheros puesto que sus rutas absolutas han cambiado." Se podría
# resolver usando la opción -execdir en vez de -exec y la opción -depth,
# pero no he podido poner todos los comandos en una tubería. En este
# caso sí funciona: find $1 -depth -execdir rename 'tr/A-Z/a-z/' "{}" \+
#
# En este guión está resuelto con la opción -depth y separando la
# ruta del nombre del fichero y luego modificando solo el nombre del
# fichero. Si solo usamos -depth no vale porque sed modifica también
# la ruta. Si solo usamos el separar ruta y nombre no funciona porque se
# modifican las rutas más cercanas a la raíz de búsqueda y luego los
# nombres de las ramas ya no coinciden con los que find encontró primero.

if [ $# -ne 1 ]
then
  echo "Uso: "${0##*/}" ruta"
  exit 0
fi

find $1 -depth -name '* *' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/ /_/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done
