#!/bin/bash
#
#===============================================================================
# Renombra ficheros *.jpg y *.mpg, con el patrón que le demos, en el
# directorio en curso.
#===============================================================================
#
#  "s/\(.*\.\)\(.*\)/$1\.\2/g"
# '.*\.' busca cualquier numero de caracteres ('.' significa un caracter,
# y seguido por '*' significa cualquier numero de caracteres) hasta
# que se encuentra el punto que separa la extension. Usamos comillas
# dobles en vez de simples para poder usar la variable $1 y que bash
# la expanda.  Se escapan todos los paréntesis, asteriscos y el punto
# de la extensión.  El segundo patron de busqueda se mantiene en la
# cadena sustituida y se indica con \2.

# Se pone 's/viejo_con_dolar-\$/nuevo_sin_dolar/g' para que bash no
# expanda nada, pero sed sí lo expande, por eso escapamos \$ si no
# queremos que sed lo interprete como fin de línea. Mejor que ''
# es poner " ", así bash sí expande las variables, pero nada más,
# evitándonos problemas.
#

if [ $# -ne 1 ] 
then
  echo "Uso: "${0##*/}" patron_para_renombrar"
  exit 0
fi

# Cambiamos el nombre de los archivos con extensión jpg

i=1
find -maxdepth 1 -iname '*.jpg' | sort -V | while read f
do
# Para generar patron-01, patron-02 en vez de patron-1, patron-2
  if [[ "$i" -lt 10 ]] ; then 
    contador=0"${i}"
  else
    contador="${i}"
  fi
  nf=`echo "${f}" | sed "s/\(.*\.\)\(.*\)/${1}-${contador}\.\2/g"`
  let i++
  mv -v "$f" "$nf"
done

# Cambiamos el nombre de los archivos con extensión mpg

i=1
find -maxdepth 1 -iname '*.mpg' | sort -V | while read f
do
# Para generar patron-01, patron-02 en vez de patron-1, patron-2
  if [[ "$i" -lt 10 ]] ; then 
    contador=0"${i}"
  else
    contador="${i}"
  fi
  nf=`echo "$f" | sed "s/\(.*\.\)\(.*\)/${1}-${contador}\.\2/g"`
  let i++
  mv -v "$f" "$nf"
done
