#!/bin/bash
#
#===============================================================================
# Cambia recursivamente a n y a las vocales sin acentuar (minusculas
# y mayusculas).
#===============================================================================
#
# acentos_y_n.sh: real	0m6.484s user	0m2.700s  sys	0m4.224s
#
# recorre_arbol_if_acentos_y_n.sh: real  1m11.209s user  0m27.350s
# sys	0m53.091s
#
# recorre_arbol_find_acentos_y_n.sh: real  1m9.557s user   0m26.614s
# sys	0m52.207s
#
# Para este código genérico de modificación de nombres de fichero:
#
#find $1 -depth -name '*ñ*' | while read fichero
#do nuevofichero=`echo "$fichero" | sed 's/ñ/n/g'`
#mv "$fichero" "$nuevofichero"
#done
#
# es necesario ejecutarlo varias veces porque find realiza una búsqueda
# inicial con los nombres originales y conforme van cambiando los nombres
# de los directorios llega un momento en que ya no se encuentran los
# ficheros puesto que sus rutas absolutas han cambiado." Se podría
# resolver usando la opción -execdir en vez de -exec y la opción
# -depth, pero no he podido poner todos los comandos en una tubería. En
# minusculas.sh sí funciona: find $1 -depth -execdir rename 'tr/A-Z/a-z/'
# "{}" \+
#
# En este guión está resuelto con la opción -depth y separando la
# ruta del nombre del fichero y luego modificando solo el nombre del
# fichero. Si solo usamos -depth no vale porque sed modifica también
# la ruta. Si solo usamos el separar ruta y nombre no funciona porque se
# modifican las rutas más cercanas a la raíz de búsqueda y luego los
# nombres de las ramas ya no coinciden con los que find encontró primero.
#

if [ $# -ne 1 ]
then
  echo "Uso: "${0##*/}" ruta"
  exit 0
fi

find $1 -depth -name '*ñ*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/ñ/n/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*Ñ*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/Ñ/N/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*á*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/á/a/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*é*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/é/e/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*í*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/í/i/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*ó*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/ó/o/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*ú*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/ú/u/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*Á*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/Á/A/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*É*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/É/E/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*Í*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/Í/I/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*Ó*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/Ó/O/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done

find $1 -depth -name '*Ú*' | while read fichero
do
  ruta="${fichero%/*}"  
  nombre="${fichero##*/}"
  nuevonombre=`echo "$nombre" | sed 's/Ú/U/g'`
  mv "${ruta}/""$nombre" "${ruta}/""$nuevonombre"
done
